@@ -250,9 +250,9 @@ class GMail():
         print(f'Found {len(messages)} messages')
         return messages
     
-    def fetchEmails(self, searchTerm, userId='me', subject=None, label=None, hasAttachment=False, maxResults=None, pageToken=None, includeSpamTrash=False, getAttachments=False, directory='../downloads'):
+    def fetchEmails(self, searchTerm, directory, userId='me', subject=None, label=None, hasAttachment=False, maxResults=None, pageToken=None, includeSpamTrash=False, getAttachments=False):
         '''
-        directory: relative path to destination folder
+        directory: path to destination folder
         '''
 
         emailIds = self.fetchEmailIds(searchTerm, userId=userId, subject=subject, label=label, hasAttachment=hasAttachment, maxResults=maxResults, pageToken=pageToken, includeSpamTrash=includeSpamTrash)
@@ -293,9 +293,7 @@ class GMail():
                         attachmentId = part['body']['attachmentId']
                         attachment = self.service.users().messages().attachments().get(userId='me', messageId=emailId['id'], id=attachmentId).execute()
                         file_data = base64.urlsafe_b64decode(attachment['data'].encode('UTF-8'))
-                        dirname = os.path.dirname(__file__)
-                        filename = f"{directory}/{emailId['id']}_{part['filename']}"
-                        filename = os.path.join(dirname, filename)
+                        filename = os.path.join(directory, f"{emailId['id']}_{part['filename']}")
                         with open(filename, 'wb') as f:
                             f.write(file_data)
                         message['attachments'].extend([filename])
